<?php

use Illuminate\Support\Facades\Route;
use App\Http\Controllers\Frontend as FrontendController;
use App\Http\Controllers\Backend as BackendController;

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| contains the "web" middleware group. Now create something great!
|
*/

Route::get('/login', [FrontendController\AuthController::class, 'login'])->name('page.login');
Route::post('/login', [FrontendController\AuthController::class, 'signin'])->name('page.signin');
Route::get('/register', [FrontendController\AuthController::class, 'register'])->name('page.register');
Route::post('/register', [FrontendController\AuthController::class, 'signup'])->name('page.signup');

Route::get('auth/google', [FrontendController\GoogleController::class, 'redirectToGoogle']);
Route::get('auth/google/callback', [FrontendController\GoogleController::class, 'handleGoogleCallback']);

Route::get('/', [FrontendController\PageController::class, 'home'])->name('page.home');
Route::get('/terms-conditions', [FrontendController\PageController::class, 'termsConditions'])->name('page.termsConditions');
Route::get('/privacy-policy', [FrontendController\PageController::class, 'privacyPolicy'])->name('page.privacyPolicy');
Route::get('/thankyou', [FrontendController\PageController::class, 'thankyou'])->name('page.thankyou');
// Route::get('/', [FrontendController\PageController::class, 'prepaid'])->name('page.prepaid');
Route::get('/prepaid', [FrontendController\PageController::class, 'shop'])->name('page.shop');
Route::get('/prepaid/{param}', [FrontendController\PageController::class, 'shopFilters'])->name('page.shop.filters');
Route::get('/product/{id}', [FrontendController\PageController::class, 'product'])->name('page.product');
Route::post('/subscribe', [FrontendController\PageController::class, 'subscribe'])->name('page.subscribe');
Route::get('search', [FrontendController\PageController::class, 'search'])->name('page.search');
Route::get('faq', [FrontendController\PageController::class, 'faq'])->name('page.faq');
Route::get('support-center', [FrontendController\PageController::class, 'supportCenter'])->name('page.supportCenter');
Route::get('support-center/{id}', [FrontendController\PageController::class, 'supportCenterSingle'])->name('page.supportCenterSingle');
Route::get('business', [FrontendController\PageController::class, 'contactus'])->name('page.contactus');
Route::post('booking', [FrontendController\PageController::class, 'booking'])->name('page.booking');
Route::get('booking/{ir}', [FrontendController\PageController::class, 'bookingIr'])->name('page.bookingIr');
Route::get('blog/{id}', [FrontendController\PageController::class, 'blog'])->name('page.blog');
Route::get('hmo', [FrontendController\PageController::class, 'information'])->name('page.information');
Route::post('quote/{provider}/{version}', [FrontendController\PageController::class, 'quote'])->name('page.quote');
Route::get('result-filter/{type}/{value}', [FrontendController\PageController::class, 'setResultFilter'])->name('page.setResultFilter');
Route::get('travel-filter/{type}/{value}', [FrontendController\PageController::class, 'setTravelFilter']);

Route::get('travel-filtering/{value}', [FrontendController\PageController::class, 'travelFiltering']);

Route::get('result', [FrontendController\PageController::class, 'result'])->name('page.result');
Route::get('result-start', [FrontendController\PageController::class, 'resultStart'])->name('page.resultStart');
Route::get('result-max', [FrontendController\PageController::class, 'resultMax'])->name('page.resultMax');
Route::get('submitted/{provider}/{planDetails}', [FrontendController\PageController::class, 'submitted'])->name('page.submitted');
Route::get('careers', [FrontendController\PageController::class, 'careers'])->name('page.careers');
Route::get('affiliate', [FrontendController\PageController::class, 'affiliate'])->name('page.affiliate');
Route::post('affiliate-application', [FrontendController\PageController::class, 'affiliateApplication'])->name('page.affiliateApplication');
Route::post('life-insurance', [FrontendController\PageController::class, 'lifeInsurance'])->name('page.life-insurance');
Route::post('nonlife-insurance', [FrontendController\PageController::class, 'nonlifeInsurance'])->name('page.nonlife-insurance');
Route::get('about-us', [FrontendController\PageController::class, 'aboutUs'])->name('page.aboutUs');

Route::post('request-quote', [FrontendController\PageController::class, 'quoteNonelife']);

Route::get('export', [FrontendController\PageController::class, 'export']);

Route::resource('compare-hmo', FrontendController\CompareHmoController::class);
Route::resource('compare', FrontendController\CompareController::class);
Route::resource('cart', FrontendController\CartController::class);
Route::resource('payment', FrontendController\PaymentController::class);
Route::resource('promo', FrontendController\PromoController::class);

Route::prefix('health')->group(function () {
    Route::get('/', [FrontendController\PageController::class, 'axaHome'])->name('page.axaHome');
    Route::get('global-health-access', [FrontendController\PageController::class, 'globalHealthAccess'])->name('page.globalHealthAccess');
    Route::get('health-care-access', [FrontendController\PageController::class, 'healthCareAccess'])->name('page.healthCareAccess');
    Route::get('HealthMaxPlan', [FrontendController\PageController::class, 'healthMax'])->name('page.healthMax');
    Route::get('health-start', [FrontendController\PageController::class, 'healthStart'])->name('page.healthStart');
});

Route::prefix('nonlife')->group(function () {
    Route::get('/', [FrontendController\PageController::class, 'nonlife'])->name('page.nonlife');
    Route::get('/{title}/v1', [FrontendController\PageController::class, 'nonlifeSingle'])->name('page.nonlifeSingle');
    Route::get('pet', [FrontendController\PageController::class, 'pet'])->name('page.pet');
    Route::post('pet', [FrontendController\PageController::class, 'petMail'])->name('page.petMail');
    Route::get('car', [FrontendController\PageController::class, 'car'])->name('page.car');
    Route::get('fire', [FrontendController\PageController::class, 'condo'])->name('page.condo');
    Route::get('house', [FrontendController\PageController::class, 'house'])->name('page.house');
    Route::get('family', [FrontendController\PageController::class, 'family'])->name('page.family');
    Route::get('accident-insurance', [FrontendController\PageController::class, 'accidentInsurance'])->name('page.accident');
    Route::get('ofw', [FrontendController\PageController::class, 'ofw'])->name('page.ofw');
    Route::get('ofw-form', [FrontendController\PageController::class, 'ofwForm'])->name('page.ofwForm');
    Route::post('ofw-form', [FrontendController\PageController::class, 'ofwFormSubmit'])->name('page.ofwFormSubmit');

    Route::get('bonds', [FrontendController\PageController::class, 'bonds'])->name('page.bonds');
    Route::get('business-insurance', [FrontendController\PageController::class, 'businessInsurance'])->name('page.business-insurance');
    Route::get('engineering-insurance', [FrontendController\PageController::class, 'engineeringInsurance'])->name('page.engineering-insurance');
    Route::get('general-liability', [FrontendController\PageController::class, 'generalLiability'])->name('page.general-liability');
    Route::get('marine-insurance', [FrontendController\PageController::class, 'marineInsurance'])->name('page.marine-insurance');

    Route::get('travel', [FrontendController\PageController::class, 'travel'])->name('page.travel');
    Route::get('axa-travel-details', [FrontendController\PageController::class, 'axaTravelDetails'])->name('page.axaTravelDetails');
    Route::get('malayan-travel-details', [FrontendController\PageController::class, 'malayanTravelDetails'])->name('page.malayanTravelDetails');

    Route::match(['post', 'get'], 'travel-form', [FrontendController\PageController::class, 'travelForm'])->name('page.travelForm');
    // Route::match(['post','get'],'malayan-select-plan',[FrontendController\PageController::class,'malayanSelectPlan'])->name('page.malayanSelectPlan');
    Route::post('malayan-travel-form2', [FrontendController\PageController::class, 'malayanTravelForm2'])->name('page.malayanTravelForm2');

    Route::post('travel-form-submit', [FrontendController\PageController::class, 'travelFormSubmit'])->name('page.travelFormSubmit');

    Route::match(['post', 'get'], 'travel-form-1', [FrontendController\PageController::class, 'travelForm1'])->name('page.travelForm1');
    Route::match(['post', 'get'], 'travel-form-2', [FrontendController\PageController::class, 'travelForm2'])->name('page.travelForm2');
    // Route::post('travel-form-submit',[FrontendController\PageController::class,'travelFormSubmit'])->name('page.travelFormSubmit');
    Route::get('motorcycle', [FrontendController\PageController::class, 'motorcycleClassic'])->name('page.motorcycle-classic');
    Route::get('motorcycle-lite', [FrontendController\PageController::class, 'motorcycleLite'])->name('page.motorcycle-lite');
});

Route::prefix('download')->group(function () {
    Route::post('pdf/{provider}', [FrontendController\DownloadController::class, 'getPdf']);
});


Route::middleware(['auth.user', 'auth'])->group(function () {
    Route::post('/logout', [FrontendController\AuthController::class, 'signout'])->name('page.logout');
    Route::post('/change-password', [FrontendController\AuthController::class, 'changePassword'])->name('page.changePassword');
    Route::post('/update-profile', [FrontendController\AuthController::class, 'updateProfile'])->name('page.updateProfile');
    Route::post('/referral', [FrontendController\AuthController::class, 'referral'])->name('page.referral');
    Route::get('/my-account', [FrontendController\PageController::class, 'myAccount'])->name('page.myaccount');
    Route::get('/orders', [FrontendController\PageController::class, 'orders'])->name('page.orders');
});

Route::get('success', [FrontendController\PageController::class, 'success'])->name('page.success');
Route::get('error', [FrontendController\PageController::class, 'error'])->name('page.error');

Route::prefix('admin')->group(function () {
    Route::get('/login', [BackendController\AuthController::class, 'login']);
    Route::post('/login', [BackendController\AuthController::class, 'signin']);

    Route::middleware('auth.cms')->group(function () {
        Route::post('/logout', [BackendController\AuthController::class, 'signout']);

        Route::get('/dashboard', [BackendController\DashboardController::class, 'dashboard']);
        Route::resource('testimonials', BackendController\TestimonialController::class);
        Route::resource('banners', BackendController\BannerController::class);
        Route::resource('type-of-insurance', BackendController\TypeOfInsuranceController::class);
        Route::resource('quote-template', BackendController\QuoteTemplateController::class);
        Route::resource('nonlife-quote-template', BackendController\NonlifeQuoteTemplateController::class);
        Route::resource('testimonial-banner', BackendController\TestimonialBannerController::class);

        Route::prefix('providers')->group(function () {
            Route::resource('prepaid', BackendController\PrepaidProviderController::class);
            Route::resource('hmo', BackendController\HmoProviderController::class);
        });

        Route::resource('products', BackendController\ProductController::class);

        Route::prefix('plan')->group(function () {
            Route::resource('hmo', BackendController\Plan\HmoController::class);
            Route::post('hmo/delete-all', [BackendController\Plan\HmoController::class, 'multipleDestroy'])->name('page.multipleDestroy');
            Route::post('hmo/hide-all', [BackendController\Plan\HmoController::class, 'multipleHide'])->name('page.multipleHide');
            Route::post('hmo/unhide-all', [BackendController\Plan\HmoController::class, 'multipleUnHide'])->name('page.multipleUnHide');
            Route::post('hmo/duplicate', [BackendController\Plan\HmoController::class, 'duplicate'])->name('page.duplicate');
            Route::resource('start', BackendController\Plan\StartController::class);
            Route::resource('max', BackendController\Plan\MaxController::class);
        });

        Route::prefix('travel')->group(function () {
            Route::resource('malayan', BackendController\Travel\MalayanController::class);
            Route::post('malayan/delete-all', [BackendController\Travel\MalayanController::class, 'multipleDestroy'])->name('page.multipleDestroy');
            Route::post('malayan/hide-all', [BackendController\Travel\MalayanController::class, 'multipleHide'])->name('page.multipleHide');
            Route::post('malayan/unhide-all', [BackendController\Travel\MalayanController::class, 'multipleUnHide'])->name('page.multipleUnHide');
            Route::post('malayan/duplicate', [BackendController\Travel\MalayanController::class, 'duplicate'])->name('page.duplicate');
        });

        Route::resource('plans', BackendController\PlanController::class);
        Route::get('plans/{type}/{action}', [BackendController\PlanController::class, 'age'])->name('page.age');
        Route::resource('orders', BackendController\OrderController::class);
        Route::post('orders', [BackendController\OrderController::class, 'multipleDestroy'])->name('page.multipleDestroy');
        Route::resource('subscribers', BackendController\SubscriberController::class);
        Route::post('subscribers', [BackendController\SubscriberController::class, 'multipleDestroy'])->name('page.multipleDestroy');
        Route::resource('bookings', BackendController\BookingController::class);
        Route::post('bookings', [BackendController\BookingController::class, 'multipleDestroy'])->name('page.multipleDestroy');
        Route::resource('quotes', BackendController\QuoteController::class);
        Route::post('quotes', [BackendController\QuoteController::class, 'multipleDestroy'])->name('page.multipleDestroy');
        Route::resource('vouchers', BackendController\VoucherController::class);
        Route::resource('physical-card', BackendController\PhysicalCardController::class);
        Route::resource('contact-us-content', BackendController\ContactUsContentController::class);
        Route::resource('axa-home-content', BackendController\AxaHomeContentController::class);
        Route::resource('email-phone', BackendController\EmailPhoneController::class);
        Route::resource('automated-text', BackendController\AutomatedTextController::class);
        Route::resource('quote-automated-text', BackendController\AutomatedTextController::class);
        Route::resource('booking-automated-text', BackendController\AutomatedTextController::class);
        Route::resource('trusted-providers', BackendController\TrustedProviderController::class);
        Route::resource('axa-accredited', BackendController\AxaAccreditedController::class);
        Route::resource('gha-accredited', BackendController\GhaAccreditedController::class);
        Route::resource('hca-accredited', BackendController\HcaAccreditedController::class);
        Route::resource('update-brochure', BackendController\UpdateBrochureController::class);
        Route::resource('referrals', BackendController\ReferralController::class);
        Route::resource('users', BackendController\UserController::class);
        Route::resource('affiliates', BackendController\AffiliateController::class);
        Route::resource('blogs', BackendController\BlogController::class);
        Route::resource('support-center', BackendController\SupportCenterController::class);
        Route::resource('faq-content', BackendController\FaqContentController::class);
        Route::resource('nonlife', BackendController\NonlifeController::class);
        Route::resource('career', BackendController\CareerController::class);
    });
});


Route::get('test', function () {
    $test = 3 / 5;

    $whole = floor($test);      // 1
    $fraction = $test - $whole;
    if ($fraction <= 0.5) {
        return 'below';
    } else {
        return 'above';
    }
    return $fraction;

    // return float($test);
    return is_float($test);
    return round($test + 1);
    if (3 <= 5) {
        $test = 1;
    }
    return $test;
    // return if(3 >= 5) { return 1 };
});

// require __DIR__.'/auth.php';
